<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DTO;
use Teknisa\MAN\Utilities;
use Zeedhi\Framework\DataSource\Manager;
use Teknisa\MAN\Services;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DataSource\DataSet;

class DescontosPorQuantidade extends Crud{
    protected $dataSourceName = 'vnd05800_descontoPorQuantidade';
    protected $util;
    protected $service;
    
    const MENSAGEM = "Quantidade inicial e final já cadastrada para  o Grupo e Sub-Grupos informados.";
    
    public function __construct (Manager $manager, Utilities\Util $util, Services\DescontosPorQuantidade $service){
        $this->util = $util;
        $this->service = $service;
        parent::__construct($manager);
    }
    
    public function save(DTO\Request\DataSet $request, DTO\Response $response){
        $params = $this->util->getParamsAsArray($request);
        $params = $params[0];
        $totalRegistros = 0;
        if($params['__is_new']){
            $totalRegistros = $this->service->checkRestricao($params);
        }
        if($totalRegistros > 0){
            $response->addMessage(new Message(self::MENSAGEM, Message::TYPE_WARNING));
        }else{
            foreach ($request->getDataSet()->getRows() as &$row) {
                $row['QTPERCDESC'] = (float)$row['QTPERCDESC'];
                $row['QTPERCDESC_inline'] = $row['QTPERCDESC']; 
            }
            self::saveWithoutNotification($request,$response);
        }
    }
    
    public function delete(DTO\Request\DataSet $request, DTO\Response $response) {
        self::deleteWithoutNotification($request,$response);
    }
    
    private function saveWithoutNotification($request, $response) {
		try {
            $dataSet = $request->getDataSet();
            $dataSet->setDataSourceName($this->dataSourceName);
            $persistedRows = $this->dataSourceManager->persist($dataSet);
            $response->addDataSet(new DataSet($this->dataSourceName, $persistedRows));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
	}
    
    private function deleteWithoutNotification($request, $response) {
		try {
            $dataSet = $request->getDataSet();
            $dataSet->setDataSourceName($this->dataSourceName);
            $deletedRows = $this->dataSourceManager->delete($dataSet);
            $response->addDataSet(new DataSet($this->dataSourceName, $deletedRows));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
	}
}